@@ -8,5 +8,5 @@ theme_metadata_parse_regex = ": (.+)"
 functions_php_mytheme_regex = "(mytheme)(?=_[\w\d\sáéíóú'-.])"
 
 wordpress_constants_json_resource = \
-    "https://raw.githubusercontent.com/aheadlabs/devops-toolset/master/" \
+    "https://raw.githubusercontent.com/aheadlabs/devops-toolset/master/src/" \
     "devops_toolset/project_types/wordpress/wordpress-constants.json"
